<?
/**************************************************************************************
*    DB Framework for PHP 1.4.                                                        *
*    Copyright (C) 2004 Luca Bertoncello                                              *
*    Waltherstrae, 11D - 01067 Dresden Deutschland                                   *
*    E-Mail: lucabert@lucabert.de, lucabert@lucabert.com                              *
*    http://www.lucabert.de/  http://www.lucabert.com/                                *
*                                                                                     *
*    This program is free software; you can redistribute it and/or modify             *
*    it under the terms of the GNU General Public License as published by             *
*    the Free Software Foundation; version 2 of the License.                          *
*                                                                                     *
*    This program is distributed in the hope that it will be useful,                  *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
*    GNU General Public License for more details.                                     *
*                                                                                     *
*    You should have received a copy of the GNU General Public License                *
*    along with this program; if not, write to the Free Software                      *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA        *
**************************************************************************************/

/*
 * String Token for DBFDateTime:
 * %Y = Year              (4 digits)
 * %y = Year              (2 digits)
 * %D = Day of the month  (00..31)
 * %d = Day of the month  (0..31)
 * %M = Month             (01..12)
 * %m = Month             (1..12)
 * %H = Hour              (00..23)
 * %h = Hour              (0..23)
 * %I = Minutes           (00..59)
 * %i = Minutes           (0..59)
 * %S = Seconds           (00..59)
 * %s = Seconds           (0..59)
 */

class DBFDateTime
{
  var $day;
  var $month;
  var $year;
  var $hour;
  var $minute;
  var $second;

  function DBFDateTime($vals = '', $format = '')
  {
    $this->day    = 0;
    $this->month  = 0;
    $this->year   = 0;
    $this->hour   = 0;
    $this->minute = 0;
    $this->second = 0;
    $this->setDateTime($vals, $format);
  }

  function setDateTime($vals, $format)
  {
    $seps                   = array();
    $tokens                 = array();
    $values                 = array();

    $seps                   = split ('(\%[0-9A-Za-z])', $format);
    $tokens[0]              = strtok($format, $seps[1]);
    for($l = 2; $l < sizeof($seps); $l++)
      {
        $tokens[$l - 1]     = strtok($seps[$l]);
      }
    $values[0]              = strtok($vals, $seps[1]);
    for($l = 2; $l < sizeof($seps); $l++)
      {
        $values[$l - 1]     = strtok($seps[$l]);
      }

    for($l = 0; $l < sizeof($tokens); $l++)
      switch($tokens[$l])
        {
          case '%Y':
            $this->year     = sprintf("%04d", $values[$l]);
          break;
          case '%y':
            $this->year     = sprintf("%02d", $values[$l]);
          break;
          case '%D':
            $this->day      = sprintf("%02d", $values[$l]);
          break;
          case '%d':
            $this->day      = sprintf("%d", $values[$l]);
          break;
          case '%M':
            $this->month    = sprintf("%02d", $values[$l]);
          break;
          case '%m':
            $this->month    = sprintf("%d", $values[$l]);
          break;
          case '%H':
            $this->hour     = sprintf("%02d", $values[$l]);
          break;
          case '%h':
            $this->hour     = sprintf("%d", $values[$l]);
          break;
          case '%I':
            $this->minute   = sprintf("%02d", $values[$l]);
          break;
          case '%i':
            $this->minute   = sprintf("%d", $values[$l]);
          break;
          case '%S':
            $this->second   = sprintf("%02d", $values[$l]);
          break;
          case '%s':
            $this->second   = sprintf("%d", $values[$l]);
          break;
        }
  }

  function toString($format)
  {
    $ret  = $format;

    $ret = ereg_replace('%D', sprintf("%02d", $this->day), $ret);
    $ret = ereg_replace('%d', sprintf("%d", $this->day), $ret);
    $ret = ereg_replace('%M', sprintf("%02d", $this->month), $ret);
    $ret = ereg_replace('%m', sprintf("%d", $this->month), $ret);
    $ret = ereg_replace('%Y', sprintf("%04d", $this->year), $ret);
    $ret = ereg_replace('%y', substr(sprintf("%04d", $this->year), 2), $ret);
    $ret = ereg_replace('%H', sprintf("%02d", $this->hour), $ret);
    $ret = ereg_replace('%h', sprintf("%d", $this->hour), $ret);
    $ret = ereg_replace('%I', sprintf("%02d", $this->minute), $ret);
    $ret = ereg_replace('%i', sprintf("%d", $this->minute), $ret);
    $ret = ereg_replace('%S', sprintf("%02d", $this->second), $ret);
    $ret = ereg_replace('%s', sprintf("%d", $this->second), $ret);

    return $ret;
  }

  function dayOfWeek()
  {
    $time                   = mktime($this->hour, $this->minute, $this->second,
                                     $this->month, $this->day, $this->year);
    return(date("w", $time));
  }

  function timeStamp()
  {
    return mktime($this->hour, $this->minute, $this->second,
                  $this->month, $this->day, $this->year);
  }

  function before($date)
  {
    if($this->timeStamp() < $date->timeStamp())
      return true;
    else
      return false;
  }

  function after($date)
  {
    if($this->timeStamp() > $date->timeStamp())
      return true;
    else
      return false;
  }

  function equals($date)
  {
    if($this->timeStamp() == $date->timeStamp())
      return true;
    else
      return false;
  }
}
?>
